searchData={"content_type":"text/markdown","items":[{"doc":"Avrora \n \n\n \n\n[![Hex pm](https://img.shields.io/hexpm/v/avrora.svg?style=for-the-badge)](https://hex.pm/packages/avrora)\n[![Hex Docs](https://img.shields.io/badge/api-docs-blue.svg?style=for-the-badge)](https://hexdocs.pm/avrora)\n\n \n\n[v0.10]: https://github.com/Strech/avrora/releases/tag/v0.10.0\n[v0.12]: https://github.com/Strech/avrora/releases/tag/v0.12.0\n[v0.13]: https://github.com/Strech/avrora/releases/tag/v0.13.0\n[v0.14]: https://github.com/Strech/avrora/releases/tag/v0.14.0\n[v0.15]: https://github.com/Strech/avrora/releases/tag/v0.15.0\n[v0.16]: https://github.com/Strech/avrora/releases/tag/v0.16.0\n[v0.17]: https://github.com/Strech/avrora/releases/tag/v0.17.0\n[v0.18]: https://github.com/Strech/avrora/releases/tag/v0.18.0\n[v0.22]: https://github.com/Strech/avrora/releases/tag/v0.22.0\n[v0.23]: https://github.com/Strech/avrora/releases/tag/v0.23.0\n[v0.24]: https://github.com/Strech/avrora/releases/tag/v0.24.0\n[v0.25]: https://github.com/Strech/avrora/releases/tag/v0.25.0\n[v0.26]: https://github.com/Strech/avrora/releases/tag/v0.26.0\n[v0.28]: https://github.com/Strech/avrora/releases/tag/v0.28.0\n[1]: https://avro.apache.org/\n[2]: https://www.confluent.io/confluent-schema-registry\n[3]: https://docs.confluent.io/current/schema-registry/serializer-formatter.html#wire-format\n[4]: https://avro.apache.org/docs/1.8.1/spec.html#Object+Container+Files\n[5]: https://docs.confluent.io/current/schema-registry/serdes-develop/index.html#referenced-schemas\n[6]: https://github.com/Strech/avrora/wiki/Inter-Schema-references\n[7]: https://github.com/dasch/avro_turf\n[8]: https://www.confluent.io/blog/multiple-event-types-in-the-same-kafka-topic/#avro-unions-with-schema-references\n[9]: https://github.com/Strech/avrora/wiki/Schema-name-resolution\n[10]: https://github.com/Strech/avrora/pull/70\n[11]: https://github.com/klarna/erlavro#decoder-hooks\n[12]: https://www.erlang.org/docs/26/man/ssl#type-client_cacerts\n\n# Getting Started\n\nThis Elixir library supports convenient encoding and decoding of [Avro][1] messages.\n\nIt can read the Avro schema from local files or the [Confluent® Schema Registry][2],\ncaching data in memory for performance.\n\nIt supports reading and writing data Kafka [wire format][3] prefix and from [Object Container Files][4]\nformats. Along with [Confluent® Schema References][5] it has [Inter-Schema references][6] feature for\nolder Schema Registry versions.\n\nMany thanks to the [AvroTurf][7] Ruby gem for the initial inspiration :blue_heart:\n\n---\n\n#### If you like the project and want to support me on my sleepless nights, you can\n\n[![Support via PayPal](https://cdn.rawgit.com/twolfson/paypal-github-button/1.0.0/dist/button.svg)](https://www.paypal.com/paypalme/onistrech/eur5.0)\n[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W8367XJ)","ref":"Avrora.html","title":"Avrora","type":"module"},{"doc":"Add Avrora to `mix.exs` as a dependency\n\n```elixir\ndef deps do\n  [\n    {:avrora, \"~> 0.27\"}\n  ]\nend\n```","ref":"Avrora.html#module-add-avrora-to-your-project","title":"Add Avrora to your project - Avrora","type":"module"},{"doc":":beginner: It's recommended to configure private Avrora client [v0.17]  to avoid\nrisk of conflicts with other dependencies which might use shared `Avrora` client.\n\nDon't worry if you already using the shared client because migration to the private is a\nmatter of copy-paste.","ref":"Avrora.html#module-configuration","title":"Configuration - Avrora","type":"module"},{"doc":"Create your private Avrora client module\n\n```elixir\ndefmodule MyClient do\n  use Avrora.Client,\n    otp_app: :my_application,\n    schemas_path: \"./priv/schemas\",\n    registry_url: \"http://localhost:8081\",\n    registry_auth: {:basic, [\"username\", \"password\"]},\n    registry_user_agent: \"Avrora/0.25.0 Elixir\",\n    registry_ssl_cacerts: File.read!(\"./priv/trusted.der\"),\n    registry_ssl_cacert_path: \"./priv/trusted.crt\",\n    registry_schemas_autoreg: false,\n    convert_null_values: false,\n    convert_map_to_proplist: false,\n    names_cache_ttl: :timer.minutes(5),\n    decoder_hook: &MyClient.decoder_hook/4\nend\n```\n\nplease check the section below :point_down: for detailed explanation of each configuration option.","ref":"Avrora.html#module-private-client","title":"Private client - Avrora","type":"module"},{"doc":"Configure the `Avrora` shared client in `config/config.exs`\n\n```elixir\nconfig :avrora,\n  otp_app: :my_application, # optional, if you want to use it as a root folder for `schemas_path`\n  schemas_path: \"./priv/schemas\",\n  registry_url: \"http://localhost:8081\",\n  registry_auth: {:basic, [\"username\", \"password\"]}, # optional\n  registry_user_agent: \"Avrora/0.24.2 Elixir\", # optional: if you want to return previous behaviour, set it to `nil`\n  registry_ssl_cacerts: File.read!(\"./priv/trusted.der\"), # optional: if you have DER-encoded certificate\n  registry_ssl_cacert_path: \"./priv/trusted.crt\", # optional: if you have PEM-encoded certificate file\n  registry_schemas_autoreg: false, # optional: if you want manually register schemas\n  convert_null_values: false, # optional: if you want to keep decoded `:null` values as is\n  convert_map_to_proplist: false, # optional: if you want to restore the old behavior for decoding map-type\n  names_cache_ttl: :timer.minutes(5), # optional: if you want periodic disk reads\n  decoder_hook: &MyClient.decoder_hook/4 # optional: if you want to amend the data/result\n```\n\n- `otp_app` [v0.22]  - Name of the OTP application to use for runtime configuration via env, default `nil`\n- `schemas_path` - Base path for locally stored schema files, default `./priv/schemas`\n- `registry_url` - URL for the Schema Registry, default `nil`\n- `registry_auth` – Credentials to authenticate in the Schema Registry, default `nil`\n- `registry_user_agent` [v0.25]  - HTTP `User-Agent` header for Schema Registry requests, default `Avrora/  Elixir`\n- `registry_ssl_cacerts` [v0.28]  - DER-encoded certificates, but [without combined support][12], default `nil`\n- `registry_ssl_cacert_path` [v0.28]  - Path to a file containing PEM-encoded CA certificates, default `nil`\n- `registry_schemas_autoreg` [v0.13]  - Flag for automatic schemas registration in the Schema Registry, default `true`\n- `convert_null_values` [v0.14]  - Flag for automatic conversion of decoded `:null` values into `nil`, default `true`\n- `convert_map_to_proplist` [v0.15]  restore old behaviour and confiugre decoding map-type to proplist, default `false`\n- `names_cache_ttl` [v0.10]  - Time in ms to cache schemas by name in memory, default `:infinity`\n- `decoder_hook` [v0.24]  - Function with arity 4 to amend data or result, default `fn _, _, data, fun -> fun.(data) end`\n\nSet `names_cache_ttl` to `:infinity` will cache forever (no more disk reads will\nhappen). This is safe when schemas resolved in the Schema Registry by\nnumeric id or **versioned** name, as it is unique. If you need to reload schema\nfrom the disk periodically, TTL different from `:infinity` ensures that.\n\nIf the schema resolved by name it will be always overwritten with the latest\nschema received from Schema Registry. [v0.10] \n\nCustom [decoder hook][11] will be first in the call-chain, after it's done Avrora\nwill use the result in its own decoder hook. [v0.24] \n\n:bulb: Disable schemas auto-registration if you want to avoid storing schemas\nand manually control registration process. Also it's recommended to turn off auto-registration\nwhen schemas containing [Confluent Schema References][8]. [v0.14] \n\n:bulb: When you use releases and especially Umbrella apps with different clients it's\nrecommended to set `otp_app` which will point to your OTP applications. This will allow you\nto have a per-client runtime resolution for all configuration options (i.e. `schemas_path`)\nwith a fallback to staticly defined in a client itself. [v0.23] \n\n:bulb: If both `registry_ssl_cacerts` and `registry_ssl_cacert_path` given, then\n`registry_ssl_cacerts` has a priority.","ref":"Avrora.html#module-shared-client","title":"Shared client - Avrora","type":"module"},{"doc":"Avrora uses an in-memory cache to speed up schema lookup.","ref":"Avrora.html#module-start-cache-process","title":"Start cache process - Avrora","type":"module"},{"doc":"After you've created your [private Avrora client](#private-client),\nadd it to your supervision tree\n\n```elixir\nchildren = [\n  MyClient\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nor start the process manually\n\n```elixir\n{:ok, pid} = MyClient.start_link()\n```","ref":"Avrora.html#module-private-client","title":"Private client - Avrora","type":"module"},{"doc":"Add shared `Avrora` module to your supervision tree\n\n```elixir\nchildren = [\n  Avrora\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nor start the process manually\n\n```elixir\n{:ok, pid} = Avrora.start_link()\n```","ref":"Avrora.html#module-shared-client","title":"Shared client - Avrora","type":"module"},{"doc":":beginner: All the examples below (including [Schemas registration](#schemas-registration))\nwill use `Avrora` shared client, but if you are using private client,\njust replace `Avrora` with your client module name.\n\nThe primary way to use the library is via the `Avrora.encode/2` and\n`Avrora.decode/2` functions. These functions load the Avro schema for you.\n\nIf `registry_url` defined, it enables Schema Registry storage. If the schema\nfile found locally but not in the registry, either fuction will register the schema.\n\nThese examples assume you have a `Payment` schema stored in the file\n`priv/schemas/io/acme/Payment.avsc`\n\n```json\n{\n  \"type\": \"record\",\n  \"name\": \"Payment\",\n  \"namespace\": \"io.acme\",\n  \"fields\": [\n    {\n      \"name\": \"id\",\n      \"type\": \"string\"\n    },\n    {\n      \"name\": \"amount\",\n      \"type\": \"double\"\n    }\n  ]\n}\n```\n\nWhen running interactively, first make sure the cache started\n\n```elixir\n{:ok, pid} = Avrora.start_link()\n```","ref":"Avrora.html#module-usage","title":"Usage - Avrora","type":"module"},{"doc":"To encode a `Payment` message:\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\")\n<<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n  8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n  144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n  111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n  101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n  101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n  100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34,\n  44, 34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125,\n  44, 123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34,\n  44, 34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125,\n  93, 125, 0, 138, 124, 66, 49, 157, 51, 242, 3, 33, 52, 161, 147, 221, 174,\n  114, 48, 2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 138,\n  124, 66, 49, 157, 51, 242, 3, 33, 52, 161, 147, 221, 174, 114, 48>>\n```\n\nThe `:format` argument controls output format:\n\n- `:plain` deprecated [v0.18]  - Just return Avro binary data, with no header or embedded schema\n- `:ocf` - Use [Object Container File][4]\n  format, embedding the full schema with the data\n- `:registry` - Write data with Confluent Schema Registry\n  [Wire Format][3],\n  which prefixes the data with the schema id\n- `:guess` - Use `:registry` if possible, otherwise use `:ocf` (default)\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\", format: :registry)\n<<0, 0, 42, 0, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n```","ref":"Avrora.html#module-encode-2","title":"encode/2 - Avrora","type":"module"},{"doc":"Decode `Payment` message using the specified schema\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = <<0, 0, 42, 0, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n\n{:ok, decoded} = Avrora.decode(message, schema_name: \"io.acme.Payment\")\n%{\"id\" => \"tx-1\", \"amount\" => 15.99}\n```","ref":"Avrora.html#module-decode-2","title":"decode/2 - Avrora","type":"module"},{"doc":"Decode a message, auto-detecting the schema using magic bytes.\nIt first tries resolving the schema using the integer id in the [wire format][3] header.\n\nNext it tries reading using the [Object Container Files][4] embedded schema.\n\n**NOTE:** Messages encoded with OCF wrapped in a List.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage =\n  <<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n    8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n    144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n    111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n    101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n    101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n    100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125, 44,\n    123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125, 93,\n    125, 0, 84, 229, 97, 195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106,\n    2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 84, 229, 97,\n    195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106>>\n\n{:ok, decoded} = Avrora.decode(message)\n[%{\"id\" => \"tx-1\", \"amount\" => 15.99}]\n```\n\n:bulb: Due to [possible collision][10] of the `:plain` format and `:registry` via magic-like\nbyte sequence it's recommended [v0.18]  to use `Avrora.decode_plain/2` and `Avrora.encode_plain/2` if\nyou are working with `:plain` format (see in all available functions).\n\n \n   :mag: Click to expand for all available functions","ref":"Avrora.html#module-decode-1","title":"decode/1 - Avrora","type":"module"},{"doc":"Decode a message encoded in a `:plain` format.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = <<8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n\n{:ok, decoded} = Avrora.decode(message, schema_name: \"io.acme.Payment\")\n%{\"id\" => \"tx-1\", \"amount\" => 15.99}\n```","ref":"Avrora.html#module-decode_plain-2-0-18","title":"decode_plain/2 [0.18] - Avrora","type":"module"},{"doc":"Encode a payload in a `:plain` format.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\")\n<<8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n```","ref":"Avrora.html#module-encode_plain-2-0-18","title":"encode_plain/2 [0.18] - Avrora","type":"module"},{"doc":"Extracts a schema from the encoded message, useful when you would like to have\nsome metadata about the schema used to encode the message. All the retrieved schemas\nwill be cached accordingly to the settings.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage =\n  <<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n    8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n    144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n    111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n    101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n    101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n    100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125, 44,\n    123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125, 93,\n    125, 0, 84, 229, 97, 195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106,\n    2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 84, 229, 97,\n    195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106>>\n\n{:ok, schema} = Avrora.extract_schema(message)\n{:ok,\n %Avrora.Schema{\n   full_name: \"io.acme.Payment\",\n   id: nil,\n   json: \"{\\\"namespace\\\":\\\"io.acme\\\",\\\"name\\\":\\\"Payment\\\",\\\"type\\\":\\\"record\\\",\\\"fields\\\":[{\\\"name\\\":\\\"id\\\",\\\"type\\\":\\\"string\\\"},{\\\"name\\\":\\\"amount\\\",\\\"type\\\":\\\"double\\\"}]}\",\n   lookup_table: #Reference<0.146116641.3853647878.152744>,\n   version: nil\n }}\n```","ref":"Avrora.html#module-extract_schema-1","title":"extract_schema/1 - Avrora","type":"module"},{"doc":"There are two ways you can register AVRO schemas if you have disabled auto-registration.\n\nIf you want to make it a part of your code, but with better control, you can use\n`Avrora.Utils.Registrar` module and if you want to embed it in the deployment use\na mix task `avrora.reg.schema`.","ref":"Avrora.html#module-schemas-registration","title":"Schemas registration - Avrora","type":"module"},{"doc":"This module is cache-aware and thus it can be used inside intensive loops if needed.\nIt provides two ways to register schema:\n\n- by name, then it will be resolved to a file with [library conventions][9]\n- by schema, then a given schema will be used without any disk reads\n\nBut keep in mind that either way has a memory check to ensure that schema was not\nregistered before and to bypass this check you have to use `force: true` flag\n\n```elixir\n{:ok, schema} = Avrora.Utils.Registrar.register_schema_by_name(\"io.acme.Payment\", force: true)\n```\n\nIn addition, any schema can be registered under different subject via `as: \"NewName\"` option\n\n```elixir\n{:ok, schema} = Avrora.Storage.File.get(\"io.acme.Payment\")\n{:ok, schema_with_id} = Avrora.Utils.Registrar.register_schema(schema, as: \"NewName\")\n```","ref":"Avrora.html#module-avrora-utils-registrar-v0-16","title":"Avrora.Utils.Registrar [v0.16] - Avrora","type":"module"},{"doc":"A separate mix task to register a specific schema or all found schemas in\nschemas folder (see [configuration](#configuration) section).\n\nFor instance, if you configure Avrora schemas folder to be at `./priv/schemas`\nand you want to register a schema `io/acme/Payment.avsc` then you can use\nthis command\n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment\nschema `io.acme.Payment' will be registered\n```\n\nIn addition, any schema can be registered under different subject via `--as` option [v0.16] \n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment --as MyCustomName\nschema `io.acme.Payment' will be registered as `MyCustomName'\n```\n\nIf you would like to register all schemas found under `./priv/schemas` then you\ncan simply execute this command\n\n```console\n$ mix avrora.reg.schema --all\nschema `io.acme.Payment' will be registered\nschema `io.acme.Wrong' will be skipped due to an error `argument error'\n```\n\nAdditional application config to load additional can be set via `--appconfig` option [v0.26] \n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment --appconfig runtime\nschema `io.acme.Payment' will be registered\n```","ref":"Avrora.html#module-mix-avrora-reg-schema-v0-12","title":"mix avrora.reg.schema [v0.12] - Avrora","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Avrora.html#child_spec/1","title":"Avrora.child_spec/1","type":"function"},{"doc":"","ref":"Avrora.html#decode/1","title":"Avrora.decode/1","type":"function"},{"doc":"","ref":"Avrora.html#decode/2","title":"Avrora.decode/2","type":"function"},{"doc":"","ref":"Avrora.html#decode_plain/2","title":"Avrora.decode_plain/2","type":"function"},{"doc":"","ref":"Avrora.html#encode/2","title":"Avrora.encode/2","type":"function"},{"doc":"","ref":"Avrora.html#encode_plain/2","title":"Avrora.encode_plain/2","type":"function"},{"doc":"","ref":"Avrora.html#extract_schema/1","title":"Avrora.extract_schema/1","type":"function"},{"doc":"","ref":"Avrora.html#start_link/1","title":"Avrora.start_link/1","type":"function"},{"doc":"A wrapper with a bit of a login around the `:avro_binary_decoder` and\n`:avro_ocf` decoder options.","ref":"Avrora.AvroDecoderOptions.html","title":"Avrora.AvroDecoderOptions","type":"module"},{"doc":"A unified erlavro decoder options compatible for both binary and OCF decoders.","ref":"Avrora.AvroDecoderOptions.html#options/0","title":"Avrora.AvroDecoderOptions.options/0","type":"function"},{"doc":"A host process and a wrapper for :avro_schema_store produced tables.\nIt is used only to create new tables and no other functionality is coverd.\n\nThis process will be in the same supervision tree as `Avrora.Storage.Memory`\nwith a stragety `one for all`.\n\nSee more:\n  - https://github.com/Strech/avrora/issues/21\n  - https://elixirforum.com/t/do-we-need-a-process-for-ets-tables/22705","ref":"Avrora.AvroSchemaStore.html","title":"Avrora.AvroSchemaStore","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Avrora.AvroSchemaStore.html#child_spec/1","title":"Avrora.AvroSchemaStore.child_spec/1","type":"function"},{"doc":"Creates a new Erlang Term Store.","ref":"Avrora.AvroSchemaStore.html#new/0","title":"Avrora.AvroSchemaStore.new/0","type":"function"},{"doc":"iex> {:ok, _} = Avrora.AvroSchemaStore.start_link()\n    iex> Avrora.AvroSchemaStore.new() |> :ets.info() |> Keyword.get(:size)\n    0","ref":"Avrora.AvroSchemaStore.html#new/0-examples","title":"Examples: - Avrora.AvroSchemaStore.new/0","type":"function"},{"doc":"","ref":"Avrora.AvroSchemaStore.html#start_link/1","title":"Avrora.AvroSchemaStore.start_link/1","type":"function"},{"doc":"Generates client module with isolated memory storage.","ref":"Avrora.Client.html","title":"Avrora.Client","type":"module"},{"doc":"defmodule MyClient do\n       use Avrora.Client,\n         schemas_path: Path.expand(\"./priv/schemas\"),\n         registry_url: \"https://registry.io\"\n     end\n\nIt will expose `Avrora.Encoder` module functions and make `MyClient` module\nidentical to `Avrora` module, but isolated from it.\n\nTo start using `MyClient` follow the [Start cache process](README.md#start-cache-process),\nadd it to your supervision tree\n\n     children = [\n       MyClient\n     ]\n\n     Supervisor.start_link(children, strategy: :one_for_one)\n\nor start the process manually\n\n     {:ok, pid} = MyClient.start_link()","ref":"Avrora.Client.html#module-examples","title":"Examples - Avrora.Client","type":"module"},{"doc":"A behaviour for encoding/decoding Avro messages.","ref":"Avrora.Codec.html","title":"Avrora.Codec","type":"behaviour"},{"doc":"Check either a given binary Avro message is decodable with a specific codec or not.\n\nNOTE: It's not guaranteed that a decodable binary message will be successfuly decoded.","ref":"Avrora.Codec.html#c:decodable?/1","title":"Avrora.Codec.decodable?/1","type":"callback"},{"doc":"...> Avrora.Codec.Plain.decodable?(<<1, 2, 3>>)\n    true\n    ...> Avrora.Codec.SchemaRegistry.decodable?(<<1, 2, 3>>)\n    false","ref":"Avrora.Codec.html#c:decodable?/1-examples","title":"Examples - Avrora.Codec.decodable?/1","type":"callback"},{"doc":"Decode a binary Avro message into the Elixir data.","ref":"Avrora.Codec.html#c:decode/1","title":"Avrora.Codec.decode/1","type":"callback"},{"doc":"...> payload = <<0, 0, 0, 0, 8, 72, 48, 48, 48, 48, 48, 48, 48, 48, 45,\n    48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48,\n    48, 48, 48, 48, 48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> Avrora.Codec.SchemaRegistry.decode(payload)\n    {:ok, %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}}","ref":"Avrora.Codec.html#c:decode/1-examples","title":"Examples - Avrora.Codec.decode/1","type":"callback"},{"doc":"Decode a binary Avro message into the Elixir data with given schema.","ref":"Avrora.Codec.html#c:decode/2","title":"Avrora.Codec.decode/2","type":"callback"},{"doc":"...> payload = <<72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48, 48, 48, 48,\n    45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48, 48, 48,\n    48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> {:ok, schema} = Avrora.Resolver.resolve(\"io.acme.Payment\")\n    ...> Avrora.Codec.Plain.decode(payload, schema: schema)\n    {:ok, %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}}","ref":"Avrora.Codec.html#c:decode/2-examples","title":"Examples - Avrora.Codec.decode/2","type":"callback"},{"doc":"Encode the Elixir data into a binary Avro message.","ref":"Avrora.Codec.html#c:encode/2","title":"Avrora.Codec.encode/2","type":"callback"},{"doc":"...> payload = %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}\n    ...> {:ok, schema} = Avrora.Resolver.resolve(\"io.acme.Payment\")\n    ...> Avrora.Codec.Plain.encode(payload, schema: schema)\n    <<72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48,\n    48, 45, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>","ref":"Avrora.Codec.html#c:encode/2-examples","title":"Examples - Avrora.Codec.encode/2","type":"callback"},{"doc":"Extract schema from the binary Avro message.","ref":"Avrora.Codec.html#c:extract_schema/1","title":"Avrora.Codec.extract_schema/1","type":"callback"},{"doc":"...> payload = <<0, 0, 0, 0, 42, 72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48,\n    48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48,\n    48, 48, 48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> {:ok, schema} = Avrora.Codec.SchemaRegistry.extract_schema(payload)\n    ...> schema.id\n    42\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Codec.html#c:extract_schema/1-examples","title":"Examples - Avrora.Codec.extract_schema/1","type":"callback"},{"doc":"","ref":"Avrora.Codec.html#c:is_decodable/1","title":"Avrora.Codec.is_decodable/1","type":"callback"},{"doc":"An Avro encoder/decoder working with an Object Container File formatted Avro messages.\n\nIt works with a binary format, which includes a required schema inside the message.\nSee more about [Object Container File](https://avro.apache.org/docs/1.8.1/spec.html#Object+Container+Files).","ref":"Avrora.Codec.ObjectContainerFile.html","title":"Avrora.Codec.ObjectContainerFile","type":"module"},{"doc":"An Avro encoder/decoder working with a plain Avro messages.\n\nIt works with a binary format, which doesn't include any schema inside\nlike Object Container File or the magic bytes for a Schema Registry.","ref":"Avrora.Codec.Plain.html","title":"Avrora.Codec.Plain","type":"module"},{"doc":"An Avro encoder/decoder working with a Schema Registry formatted Avro messages.\n\nIt works with a binary format, which includes a required schema global ID inside the message.\nSee more about [Schema Registry](https://docs.confluent.io/current/schema-registry/serializer-formatter.html#wire-format).","ref":"Avrora.Codec.SchemaRegistry.html","title":"Avrora.Codec.SchemaRegistry","type":"module"},{"doc":"Configuration for Avrora.","ref":"Avrora.Config.html","title":"Avrora.Config","type":"behaviour"},{"doc":"* `otp_app` name of the OTP application to use for addition `schemas_path` root folder configuration, default `nil`\n    * `schemas_path` path to local schema files, default `./priv/schemas`\n    * `registry_url` URL for Schema Registry, default `nil`\n    * `registry_auth` authentication settings for Schema Registry, default `nil`\n    * `registry_user_agent` HTTP `User-Agent` header for Schema Registry requests, default `Avrora/  Elixir`\n    * `registry_ssl_opts` arbitrary SSL client options in Erlang format (take precedence over other SSL options) (see https://www.erlang.org/docs/26/man/ssl#type-client_option), default `nil`\n    * `registry_ssl_cacerts` DER-encoded trusted certificate (not combined) (see https://www.erlang.org/docs/26/man/ssl#type-client_cacerts), default `nil`\n    * `registry_ssl_cacert_path` path to a file containing PEM-encoded CA certificates, default `nil`\n    * `registry_schemas_autoreg` automatically register schemas in Schema Registry, default `true`\n    * `convert_null_values` convert `:null` values in the decoded message into `nil`, default `true`\n    * `convert_map_to_proplist` bring back old behavior and configure decoding AVRO map-type as proplist, default `false`\n    * `names_cache_ttl` duration to cache global schema names millisecods, default `:infinity`\n    * `decoder_hook` function to amend decoded payload, default `fn _, _, data, fun -> fun.(data) end`","ref":"Avrora.Config.html#module-options","title":"Options: - Avrora.Config","type":"behaviour"},{"doc":"* `file_storage` module which handles files in `schemas_path`, default `Avrora.Storage.File`\n    * `memory_storage` module which handles memory operations, default `Avrora.Storage.Memory`\n    * `registry_storage` module which handles Schema Registry requests, default `Avrora.Storage.Registry`\n    * `http_client` module which handles HTTP client requests to Schema Registry, default `Avrora.HTTPClient`\n    * `ets_lib` module which creates ETS tables with call `Module.new/0`","ref":"Avrora.Config.html#module-internal-use-interface","title":"Internal use interface: - Avrora.Config","type":"behaviour"},{"doc":"","ref":"Avrora.Config.html#c:convert_map_to_proplist/0","title":"Avrora.Config.convert_map_to_proplist/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:convert_null_values/0","title":"Avrora.Config.convert_null_values/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:decoder_hook/0","title":"Avrora.Config.decoder_hook/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:ets_lib/0","title":"Avrora.Config.ets_lib/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:file_storage/0","title":"Avrora.Config.file_storage/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:http_client/0","title":"Avrora.Config.http_client/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:memory_storage/0","title":"Avrora.Config.memory_storage/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:names_cache_ttl/0","title":"Avrora.Config.names_cache_ttl/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_auth/0","title":"Avrora.Config.registry_auth/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_schemas_autoreg/0","title":"Avrora.Config.registry_schemas_autoreg/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_ssl_cacert_path/0","title":"Avrora.Config.registry_ssl_cacert_path/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_ssl_cacerts/0","title":"Avrora.Config.registry_ssl_cacerts/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_ssl_opts/0","title":"Avrora.Config.registry_ssl_opts/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_storage/0","title":"Avrora.Config.registry_storage/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_url/0","title":"Avrora.Config.registry_url/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:registry_user_agent/0","title":"Avrora.Config.registry_user_agent/0","type":"callback"},{"doc":"","ref":"Avrora.Config.html#c:schemas_path/0","title":"Avrora.Config.schemas_path/0","type":"callback"},{"doc":"Wraps internal codec interface to add syntax sugar which will be exposed to client.","ref":"Avrora.Encoder.html","title":"Avrora.Encoder","type":"module"},{"doc":"Decode binary Avro message, loading schema from Schema Registry or Object Container Files.","ref":"Avrora.Encoder.html#decode/1","title":"Avrora.Encoder.decode/1","type":"function"},{"doc":"...> payload = <<0, 0, 0, 0, 8, 72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48,\n    48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48,\n    48, 48, 48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> Avrora.Encoder.decode(payload)\n    {:ok, %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}}","ref":"Avrora.Encoder.html#decode/1-examples","title":"Examples - Avrora.Encoder.decode/1","type":"function"},{"doc":"Decode binary Avro message, loading schema from local file or Schema Registry.","ref":"Avrora.Encoder.html#decode/2","title":"Avrora.Encoder.decode/2","type":"function"},{"doc":"...> payload = <<72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45,\n    48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48, 48, 48, 48, 48,\n    48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> Avrora.Encoder.decode(payload, schema_name: \"io.acme.Payment\")\n    {:ok, %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}}","ref":"Avrora.Encoder.html#decode/2-examples","title":"Examples - Avrora.Encoder.decode/2","type":"function"},{"doc":"Decode binary Avro message with a :plain format and load schema from local file.","ref":"Avrora.Encoder.html#decode_plain/2","title":"Avrora.Encoder.decode_plain/2","type":"function"},{"doc":"...> payload = <<0, 232, 220, 144, 233, 11, 200, 1>>\n    ...> Avrora.Encoder.decode_plain(payload,\"io.acme.NumericTransfer\")\n    {:ok, %{\"link_is_enabled\" => false, \"updated_at\" => 1586632500, \"updated_by_id\" => 100}","ref":"Avrora.Encoder.html#decode_plain/2-examples","title":"Examples - Avrora.Encoder.decode_plain/2","type":"function"},{"doc":"Encode message map in Avro format, loading schema from local file or Schema Registry.\n\nThe `:format` argument controls output format:\n\n* `:plain` - Just return Avro binary data, with no header or embedded schema\n* `:ocf` - Use [Object Container File]https://avro.apache.org/docs/1.8.1/spec.html#Object+Container+Files)\n  format, embedding the full schema with the data\n* `:registry` - Write data with Confluent Schema Registry\n  [Wire Format](https://docs.confluent.io/current/schema-registry/serializer-formatter.html#wire-format),\n  which prefixes the data with the schema id\n* `:guess` - Use `:registry` if possible, otherwise use `:ocf` (default)","ref":"Avrora.Encoder.html#encode/2","title":"Avrora.Encoder.encode/2","type":"function"},{"doc":"...> payload = %{\"id\" => \"00000000-0000-0000-0000-000000000000\", \"amount\" => 15.99}\n    ...> Avrora.Encoder.encode(payload, schema_name: \"io.acme.Payment\", format: :plain)\n    {:ok, <<72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45,\n          48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48, 48, 48, 48, 48,\n          48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>}","ref":"Avrora.Encoder.html#encode/2-examples","title":"Examples - Avrora.Encoder.encode/2","type":"function"},{"doc":"Encode binary Avro message with a :plain format and load schema from local file.","ref":"Avrora.Encoder.html#encode_plain/2","title":"Avrora.Encoder.encode_plain/2","type":"function"},{"doc":"...> payload = %{\"link_is_enabled\" => false, \"updated_at\" => 1586632500, \"updated_by_id\" => 100}\n    ...> Avrora.Encoder.encode_plain(payload,\"io.acme.NumericTransfer\")\n    {:ok, <<0, 232, 220, 144, 233, 11, 200, 1>>}","ref":"Avrora.Encoder.html#encode_plain/2-examples","title":"Examples - Avrora.Encoder.encode_plain/2","type":"function"},{"doc":"Extract schema from the binary Avro message.","ref":"Avrora.Encoder.html#extract_schema/1","title":"Avrora.Encoder.extract_schema/1","type":"function"},{"doc":"...> payload = <<0, 0, 0, 0, 8, 72, 48, 48, 48, 48, 48, 48, 48, 48, 45, 48,\n    48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 45, 48, 48, 48, 48, 48,\n    48, 48, 48, 48, 48, 48, 48, 123, 20, 174, 71, 225, 250, 47, 64>>\n    ...> {:ok, schema} = Avrora.Encoder.extract_schema(payload)\n    ...> schema.id\n    42\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Encoder.html#extract_schema/1-examples","title":"Examples - Avrora.Encoder.extract_schema/1","type":"function"},{"doc":"Minimal HTTP client using built-in Erlang `httpc` library.","ref":"Avrora.HTTPClient.html","title":"Avrora.HTTPClient","type":"behaviour"},{"doc":"","ref":"Avrora.HTTPClient.html#c:get/2","title":"Avrora.HTTPClient.get/2","type":"callback"},{"doc":"","ref":"Avrora.HTTPClient.html#c:post/3","title":"Avrora.HTTPClient.post/3","type":"callback"},{"doc":"Resolve schema name or global ID to a schema, keeping cache up to date.","ref":"Avrora.Resolver.html","title":"Avrora.Resolver","type":"module"},{"doc":"Resolve schema by integer ID or by a string name with optional version,\nthen update memory storage.\n\nIn case of an integer ID it stores schema in memory with ID key.","ref":"Avrora.Resolver.html#resolve/1","title":"Avrora.Resolver.resolve/1","type":"function"},{"doc":"...> {:ok, schema} = Avrora.Resolver.resolve(1)\n    ...> schema.full_name\n    \"io.acme.Payment\"\n\nIn case of a string name it stores schema in memory with key `name` and `name:version`,\nalso adds schema to the Schema Registry (if it's configured).\n\nA version for the name can be provided by adding `:` with the version number,\ne.g. `io.acme.Payment:5`. If the Schema Registry is configured (`:registry_url`),\nit will first try fetch there, then local schemas folder (`:schemas_path`).","ref":"Avrora.Resolver.html#resolve/1-examples","title":"Examples - Avrora.Resolver.resolve/1","type":"function"},{"doc":"...> {:ok, schema1} = Avrora.Resolver.resolve(\"io.acme.Payment\")\n    ...> {:ok, schema2} = Avrora.Resolver.resolve(\"io.acme.Payment:42\")\n    ...> schema1.version\n    42\n    ...> schema2.version\n    42\n    ...> schema1.full_name\n    \"io.acme.Payment\"\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Resolver.html#resolve/1-examples","title":"Examples - Avrora.Resolver.resolve/1","type":"function"},{"doc":"Resolve schema, trying multiple methods. First tries integer id, then string name.","ref":"Avrora.Resolver.html#resolve_any/1","title":"Avrora.Resolver.resolve_any/1","type":"function"},{"doc":"...> {:ok, schema} = Avrora.Resolver.resolve_any([1, \"io.acme.Payment\"])\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Resolver.html#resolve_any/1-examples","title":"Examples - Avrora.Resolver.resolve_any/1","type":"function"},{"doc":"Convenience wrapper struct for erlavro records.","ref":"Avrora.Schema.html","title":"Avrora.Schema","type":"module"},{"doc":"","ref":"Avrora.Schema.html#t:t/0","title":"Avrora.Schema.t/0","type":"type"},{"doc":"Encodes and parses Avro schemas from various formats, like JSON and erlavro into `Avrora.Schema`.","ref":"Avrora.Schema.Encoder.html","title":"Avrora.Schema.Encoder","type":"module"},{"doc":"Convert `erlavro` format to the Schema struct.","ref":"Avrora.Schema.Encoder.html#from_erlavro/2","title":"Avrora.Schema.Encoder.from_erlavro/2","type":"function"},{"doc":"iex> payload =\n    ...>   {:avro_record_type, \"Payment\", \"io.acme\", \"\", [],\n    ...>        [\n    ...>          {:avro_record_field, \"id\", \"\", {:avro_primitive_type, \"string\", []}, :undefined,\n    ...>           :ascending, []},\n    ...>          {:avro_record_field, \"amount\", \"\", {:avro_primitive_type, \"double\", []}, :undefined,\n    ...>           :ascending, []}\n    ...>        ], \"io.acme.Payment\", []}\n    iex> {:ok, schema} = Avrora.Schema.Encoder.from_erlavro(payload)\n    iex> schema.id\n    nil\n    iex> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Schema.Encoder.html#from_erlavro/2-examples","title":"Examples - Avrora.Schema.Encoder.from_erlavro/2","type":"function"},{"doc":"Parse Avro schema JSON and convert to the Schema struct.","ref":"Avrora.Schema.Encoder.html#from_json/2","title":"Avrora.Schema.Encoder.from_json/2","type":"function"},{"doc":"iex> json = ~s({\"namespace\":\"io.acme\",\"type\":\"record\",\"name\":\"Payment\",\"fields\":[{\"name\":\"id\",\"type\":\"string\"},{\"name\":\"amount\",\"type\":\"double\"}]})\n    iex> {:ok, schema} = Avrora.Schema.Encoder.from_json(json)\n    iex> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Schema.Encoder.html#from_json/2-examples","title":"Examples - Avrora.Schema.Encoder.from_json/2","type":"function"},{"doc":"An example of a reference lookup which returns empty JSON body","ref":"Avrora.Schema.Encoder.html#reference_lookup/1","title":"Avrora.Schema.Encoder.reference_lookup/1","type":"function"},{"doc":"","ref":"Avrora.Schema.Encoder.html#t:reference_lookup_fun/0","title":"Avrora.Schema.Encoder.reference_lookup_fun/0","type":"type"},{"doc":"Convert struct to `erlavro` format and look it up in `avro_schema_store`.","ref":"Avrora.Schema.Encoder.html#to_erlavro/1","title":"Avrora.Schema.Encoder.to_erlavro/1","type":"function"},{"doc":"iex> json = ~s({\"namespace\":\"io.acme\",\"type\":\"record\",\"name\":\"Payment\",\"fields\":[{\"name\":\"id\",\"type\":\"string\"},{\"name\":\"amount\",\"type\":\"double\"}]})\n    iex> {:ok, schema} = Avrora.Schema.Encoder.from_json(json)\n    iex> {:ok, {type, _, _, _, _, _, full_name, _}} = Avrora.Schema.Encoder.to_erlavro(schema)\n    iex> full_name\n    \"io.acme.Payment\"\n    iex> type\n    :avro_record_type","ref":"Avrora.Schema.Encoder.html#to_erlavro/1-examples","title":"Examples - Avrora.Schema.Encoder.to_erlavro/1","type":"function"},{"doc":"Struct for versioned schema names like `io.acme.Payment:42`.","ref":"Avrora.Schema.Name.html","title":"Avrora.Schema.Name","type":"module"},{"doc":"Parse schema name with optional version, returning struct.","ref":"Avrora.Schema.Name.html#parse/1","title":"Avrora.Schema.Name.parse/1","type":"function"},{"doc":"iex> Avrora.Schema.Name.parse(\"Payment\")\n    {:ok, %Avrora.Schema.Name{origin: \"Payment\", name: \"Payment\", version: nil}}\n    iex> Avrora.Schema.Name.parse(\"io.acme.Payment:42\")\n    {:ok, %Avrora.Schema.Name{origin: \"io.acme.Payment:42\", name: \"io.acme.Payment\", version: 42}}","ref":"Avrora.Schema.Name.html#parse/1-examples","title":"Examples - Avrora.Schema.Name.parse/1","type":"function"},{"doc":"","ref":"Avrora.Schema.Name.html#t:t/0","title":"Avrora.Schema.Name.t/0","type":"type"},{"doc":"Collect non local type references from `erlavro` structures.","ref":"Avrora.Schema.ReferenceCollector.html","title":"Avrora.Schema.ReferenceCollector","type":"module"},{"doc":"Collect non local type referenced types from `erlavro` structure.\n\nType definition aliases counted as type definitions too.\n\nEvery json-string type value considered to be a reference\nif it's not one of the reserved by Avro Specification types, such as:\n\n- int            - null            - enum\n- long           - boolean         - array\n- float          - string          - map\n- double         - record          - union\n- bytes          - fixed","ref":"Avrora.Schema.ReferenceCollector.html#collect/1","title":"Avrora.Schema.ReferenceCollector.collect/1","type":"function"},{"doc":"iex> json_schema = File.read!(\"test/fixtures/schemas/io/acme/Account.avsc\")\n    iex> erlavro = :avro_json_decoder.decode_schema(json_schema, allow_bad_references: true)\n    iex> Avrora.Schema.ReferenceCollector.collect(erlavro)\n    {:ok, [\"io.acme.Email\", \"io.acme.Messenger\", \"io.acme.PaymentHistory\"]}","ref":"Avrora.Schema.ReferenceCollector.html#collect/1-examples","title":"Examples - Avrora.Schema.ReferenceCollector.collect/1","type":"function"},{"doc":"Behavior for storing and retrieving schemas by name or integer ID.","ref":"Avrora.Storage.html","title":"Avrora.Storage","type":"behaviour"},{"doc":"","ref":"Avrora.Storage.html#c:get/1","title":"Avrora.Storage.get/1","type":"callback"},{"doc":"","ref":"Avrora.Storage.html#c:put/2","title":"Avrora.Storage.put/2","type":"callback"},{"doc":"Schema indentifier.","ref":"Avrora.Storage.html#t:schema_id/0","title":"Avrora.Storage.schema_id/0","type":"type"},{"doc":"`Avora.Storage` behavior implementation which uses the filesystem.\n\nSchema name ` . . ` will be stored to path\n`namespace/namespace/name.avsc`.","ref":"Avrora.Storage.File.html","title":"Avrora.Storage.File","type":"module"},{"doc":"Read schema from disk by full name, including namespace.\n\nFiles are stored with each namespace component as a folder name.\nFor example `io.acme.Payment` should be stored as follows:\n\n    .\n    ├── lib/\n    ├── priv/\n    │   ├── ...\n    │   └── schemas/\n    │       └── io/\n    │           └── acme/\n    │               └── Payment.avsc\n    └── ...","ref":"Avrora.Storage.File.html#get/1","title":"Avrora.Storage.File.get/1","type":"function"},{"doc":"iex> {:ok, schema} = Avrora.Storage.File.get(\"io.acme.Payment\")\n    iex> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Storage.File.html#get/1-examples","title":"Examples - Avrora.Storage.File.get/1","type":"function"},{"doc":"`Avora.Storage` behavior implementation which uses memory (ETS).\n\nSchemas can be accessed by integer id or full name.","ref":"Avrora.Storage.Memory.html","title":"Avrora.Storage.Memory","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Avrora.Storage.Memory.html#child_spec/1","title":"Avrora.Storage.Memory.child_spec/1","type":"function"},{"doc":"Delete data from storage by key. Always succeeds, whether or not the key exists.","ref":"Avrora.Storage.Memory.html#delete/1","title":"Avrora.Storage.Memory.delete/1","type":"function"},{"doc":"iex> _ = Avrora.Storage.Memory.start_link()\n    iex> schema = %Avrora.Schema{id: nil, json: \"{}\"}\n    iex> Avrora.Storage.Memory.put(\"my-key\", schema)\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}\n    iex> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}\n    iex> Avrora.Storage.Memory.delete(\"my-key\")\n    {:ok, true}\n    iex> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, nil}","ref":"Avrora.Storage.Memory.html#delete/1-examples","title":"Examples - Avrora.Storage.Memory.delete/1","type":"function"},{"doc":"Tell storage module to delete data after TTL (time to live) expires. Works whether or not the key exists.\nTTL is in milliseconds.","ref":"Avrora.Storage.Memory.html#expire/2","title":"Avrora.Storage.Memory.expire/2","type":"function"},{"doc":"...> _ = Avrora.Storage.Memory.start_link()\n    ...> schema = %Avrora.Schema{id: nil, json: \"{}\"}\n    ...> Avrora.Storage.Memory.put(\"my-key\", schema)\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}\n    ...> {:ok, _} = Avrora.Storage.Memory.expire(\"my-key\", 100)\n    ...> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}\n    ...> Process.sleep(200)\n    ...> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, nil}","ref":"Avrora.Storage.Memory.html#expire/2-examples","title":"Examples - Avrora.Storage.Memory.expire/2","type":"function"},{"doc":"Complete clean up of the storage. Useful for testing.","ref":"Avrora.Storage.Memory.html#flush/0","title":"Avrora.Storage.Memory.flush/0","type":"function"},{"doc":"iex> _ = Avrora.Storage.Memory.start_link()\n    iex> schema = %Avrora.Schema{id: nil, json: \"{}\"}\n    iex> Avrora.Storage.Memory.put(\"my-key\", schema)\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}\n    iex> {:ok, _} = Avrora.Storage.Memory.flush()\n    iex> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, nil}","ref":"Avrora.Storage.Memory.html#flush/0-examples","title":"Examples - Avrora.Storage.Memory.flush/0","type":"function"},{"doc":"Get schema by key.","ref":"Avrora.Storage.Memory.html#get/1","title":"Avrora.Storage.Memory.get/1","type":"function"},{"doc":"iex> _ = Avrora.Storage.Memory.start_link()\n    iex> Avrora.Storage.Memory.put(\"my-key\", %{\"hello\" => \"world\"})\n    {:ok, %{\"hello\" => \"world\"}}\n    iex> Avrora.Storage.Memory.get(\"my-key\")\n    {:ok, %{\"hello\" => \"world\"}}\n    iex> Avrora.Storage.Memory.get(\"unknown-key\")\n    {:ok, nil}","ref":"Avrora.Storage.Memory.html#get/1-examples","title":"Examples - Avrora.Storage.Memory.get/1","type":"function"},{"doc":"Store schema by key. If value already exists it will be replaced.","ref":"Avrora.Storage.Memory.html#put/2","title":"Avrora.Storage.Memory.put/2","type":"function"},{"doc":"iex> _ = Avrora.Storage.Memory.start_link()\n    iex> schema = %Avrora.Schema{id: nil, json: \"{}\"}\n    iex> Avrora.Storage.Memory.put(\"my-key\", schema)\n    {:ok, %Avrora.Schema{id: nil, json: \"{}\"}}","ref":"Avrora.Storage.Memory.html#put/2-examples","title":"Examples - Avrora.Storage.Memory.put/2","type":"function"},{"doc":"","ref":"Avrora.Storage.Memory.html#start_link/1","title":"Avrora.Storage.Memory.start_link/1","type":"function"},{"doc":"`Avora.Storage` behavior implementation which uses [Confluent Schema\nRegistry](https://docs.confluent.io/current/schema-registry/develop/api.html).\n\nThis only implements the minimum client functionality needed to talk with the registry.\nInspired by [Schemex](https://github.com/bencebalogh/schemex).","ref":"Avrora.Storage.Registry.html","title":"Avrora.Storage.Registry","type":"module"},{"doc":"Get schema by integer ID or by the subject name.\n\nIf subject name was used by default the latest version will be used\nunless it explicitly given (e.g `io.acme.Payment:1`).","ref":"Avrora.Storage.Registry.html#get/1","title":"Avrora.Storage.Registry.get/1","type":"function"},{"doc":"...> {:ok, schema} = Avrora.Storage.Registry.get(1)\n    ...> schema.full_name\n    \"io.acme.Payment\"\n    ...> {:ok, schema} = Avrora.Storage.Registry.get(\"io.acme.Payment\")\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Storage.Registry.html#get/1-examples","title":"Examples - Avrora.Storage.Registry.get/1","type":"function"},{"doc":"Register new version of schema under subject name.","ref":"Avrora.Storage.Registry.html#put/2","title":"Avrora.Storage.Registry.put/2","type":"function"},{"doc":"...> schema = ~s({\"fields\":[{\"name\":\"id\",\"type\":\"string\"},{\"name\":\"amount\",\"type\":\"double\"}],\"name\":\"Payment\",\"namespace\":\"io.acme\",\"type\":\"record\"})\n    ...> {:ok, schema} = Avrora.Storage.Registry.put(\"io.acme.examples.Payment\", schema)\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Storage.Registry.html#put/2-examples","title":"Examples - Avrora.Storage.Registry.put/2","type":"function"},{"doc":"Storage behavior which allows keys to be removed or expired.","ref":"Avrora.Storage.Transient.html","title":"Avrora.Storage.Transient","type":"behaviour"},{"doc":"","ref":"Avrora.Storage.Transient.html#c:delete/1","title":"Avrora.Storage.Transient.delete/1","type":"callback"},{"doc":"","ref":"Avrora.Storage.Transient.html#c:expire/2","title":"Avrora.Storage.Transient.expire/2","type":"callback"},{"doc":"","ref":"Avrora.Storage.Transient.html#c:flush/0","title":"Avrora.Storage.Transient.flush/0","type":"callback"},{"doc":"Naive timestamp with second precision.","ref":"Avrora.Storage.Transient.html#t:timestamp/0","title":"Avrora.Storage.Transient.timestamp/0","type":"type"},{"doc":"An ExUnit helper.","ref":"Avrora.TestCase.html","title":"Avrora.TestCase","type":"module"},{"doc":"A hook function to be used in `setup`-hook to clean memory storage.","ref":"Avrora.TestCase.html#cleanup_storage!/1","title":"Avrora.TestCase.cleanup_storage!/1","type":"function"},{"doc":"defmodule MyTest do\n        use ExUnit.Case, async: true\n\n        import Avrora.TestCase\n        setup :cleanup_storage!\n\n        test \"memory storage was filled\" do\n          asset Avrora.Storage.Memory.get(\"some\") == nil\n\n          Avrora.Storage.Memory.put(\"some\", 42)\n          asset Avrora.Storage.Memory.get(\"some\") == 42\n        end\n\n        test \"memory storage is clean\" do\n          asset Avrora.Storage.Memory.get(\"some\") == nil\n        end\n      end","ref":"Avrora.TestCase.html#cleanup_storage!/1-examples","title":"Examples: - Avrora.TestCase.cleanup_storage!/1","type":"function"},{"doc":"Memory store-aware schema registration with extended functionality\ndesigned to be used in the intensive loops.\n\nIt gives you control over the name under which schema will be registered\n(i.e subject in Schema Registry) and allows you to enforce registration\neven if the schema exists.","ref":"Avrora.Utils.Registrar.html","title":"Avrora.Utils.Registrar","type":"module"},{"doc":"defmodule Sample do\n      alias Avrora.Utils.Registrar\n\n      def loop do\n        Enum.reduce_while(1..100, 0, fn x, acc ->\n          if x < 100, do: {:cont, register(\"io.acme.Payment\")}, else: {:halt, acc}\n        end)\n      end\n\n      defp register(schema_name), do: Registrar.register_schema_by_name(schema_name)\n    end","ref":"Avrora.Utils.Registrar.html#module-examples","title":"Examples - Avrora.Utils.Registrar","type":"module"},{"doc":"Register schema in the Schema Registry.\n\nThis function relies on a Memory store before taking action.\nThe most complete schema name will be looked at the store, i.e if the schema\ncontains `version` then `full_name` + `version` will be used in prior just a `full_name`.","ref":"Avrora.Utils.Registrar.html#register_schema/2","title":"Avrora.Utils.Registrar.register_schema/2","type":"function"},{"doc":"* `:as` - the name which will be used to register schema (i.e subject).\n* `:force` - the flag enforcing registration when schema was found\n  in the Memory store (`false` by default).","ref":"Avrora.Utils.Registrar.html#register_schema/2-options","title":"Options - Avrora.Utils.Registrar.register_schema/2","type":"function"},{"doc":"...> {:ok, schema} = Avrora.Resolver.resolve(\"io.acme.Payment\")\n    ...> {:ok, schema} = Avrora.Utils.Registrar.register_schema(schema, as: \"NewName\", force: true)\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Utils.Registrar.html#register_schema/2-examples","title":"Examples - Avrora.Utils.Registrar.register_schema/2","type":"function"},{"doc":"Register schema from local schema file in the Schema Registry.\n\nSchema name conventions inherited from `Avrora.Storage.File.get/1`.\nFor extended documentation about registration process see `register_schema/2`.","ref":"Avrora.Utils.Registrar.html#register_schema_by_name/2","title":"Avrora.Utils.Registrar.register_schema_by_name/2","type":"function"},{"doc":"* `:as` - the name which will be used to register schema (i.e subject).\n* `:force` - the flag enforcing registration when schema was found\n  in the Memory store (`false` by default).","ref":"Avrora.Utils.Registrar.html#register_schema_by_name/2-options","title":"Options - Avrora.Utils.Registrar.register_schema_by_name/2","type":"function"},{"doc":"...> {:ok, schema} = Avrora.Utils.Registrar.register_schema_by_name(\"io.acme.Payment\", as: \"NewName\", force: true)\n    ...> schema.full_name\n    \"io.acme.Payment\"","ref":"Avrora.Utils.Registrar.html#register_schema_by_name/2-examples","title":"Examples - Avrora.Utils.Registrar.register_schema_by_name/2","type":"function"},{"doc":"Register either one schema or all schemas in the `Avrora.Config.schemas_path`\ndirectory (or your private client schemas path).\n\n    mix avrora.reg.schema [--all] [--name NAME] [--as NEW_NAME] [--module MODULE]\n\nThe search of the schemas will be performed under path configured in `schemas_path`\nconfiguration option. One of either option must be given.","ref":"Mix.Tasks.Avrora.Reg.Schema.html","title":"mix avrora.reg.schema","type":"task"},{"doc":"* `--name` - the full name of the schema to register (exclusive with `--all`)\n  * `--as` - the name which will be used to register schema (i.e subject)\n  * `--all` - register all found schemas\n  * `--module` - the private Avrora client module (i.e MyClient)\n  * `--appconfig` - the app config file name to load from `config/` folder (i.e runtime)\n\nThe `--module` option allows to use your private Avrora client module instead of\nthe default `Avrora`.\n\nThe `--as` option is possible to use only together with `--name`.\n\nThe `--name` option expects that given schema name will comply to\n`Avrora.Storage.File` module rules.\n\nThe `--appconfig` option expects just application config file name without an extension\nand will load it additionally to default. Note: runtime config doesn't support imports!\n\nFor example, if the schema name is `io.acme.Payment` it should be stored\nas ` /io/acme/Payment.avsc`","ref":"Mix.Tasks.Avrora.Reg.Schema.html#module-command-line-options","title":"Command line options - mix avrora.reg.schema","type":"task"},{"doc":"mix avrora.reg.schema --name io.acme.Payment\n    mix avrora.reg.schema --name io.acme.Payment --as MyCustomName\n    mix avrora.reg.schema --all --appconfig runtime\n    mix avrora.reg.schema --all --module MyClient\n    mix avrora.reg.schema --all","ref":"Mix.Tasks.Avrora.Reg.Schema.html#module-usage","title":"Usage - mix avrora.reg.schema","type":"task"},{"doc":"Avrora \n \n\n \n\n[![Hex pm](https://img.shields.io/hexpm/v/avrora.svg?style=for-the-badge)](https://hex.pm/packages/avrora)\n[![Hex Docs](https://img.shields.io/badge/api-docs-blue.svg?style=for-the-badge)](https://hexdocs.pm/avrora)\n\n \n\n[v0.10]: https://github.com/Strech/avrora/releases/tag/v0.10.0\n[v0.12]: https://github.com/Strech/avrora/releases/tag/v0.12.0\n[v0.13]: https://github.com/Strech/avrora/releases/tag/v0.13.0\n[v0.14]: https://github.com/Strech/avrora/releases/tag/v0.14.0\n[v0.15]: https://github.com/Strech/avrora/releases/tag/v0.15.0\n[v0.16]: https://github.com/Strech/avrora/releases/tag/v0.16.0\n[v0.17]: https://github.com/Strech/avrora/releases/tag/v0.17.0\n[v0.18]: https://github.com/Strech/avrora/releases/tag/v0.18.0\n[v0.22]: https://github.com/Strech/avrora/releases/tag/v0.22.0\n[v0.23]: https://github.com/Strech/avrora/releases/tag/v0.23.0\n[v0.24]: https://github.com/Strech/avrora/releases/tag/v0.24.0\n[v0.25]: https://github.com/Strech/avrora/releases/tag/v0.25.0\n[v0.26]: https://github.com/Strech/avrora/releases/tag/v0.26.0\n[v0.28]: https://github.com/Strech/avrora/releases/tag/v0.28.0\n[v0.30]: https://github.com/Strech/avrora/releases/tag/v0.30.0\n[1]: https://avro.apache.org/\n[2]: https://www.confluent.io/confluent-schema-registry\n[3]: https://docs.confluent.io/current/schema-registry/serializer-formatter.html#wire-format\n[4]: https://avro.apache.org/docs/1.8.1/spec.html#Object+Container+Files\n[5]: https://docs.confluent.io/current/schema-registry/serdes-develop/index.html#referenced-schemas\n[6]: https://github.com/Strech/avrora/wiki/Inter-Schema-references\n[7]: https://github.com/dasch/avro_turf\n[8]: https://www.confluent.io/blog/multiple-event-types-in-the-same-kafka-topic/#avro-unions-with-schema-references\n[9]: https://github.com/Strech/avrora/wiki/Schema-name-resolution\n[10]: https://github.com/Strech/avrora/pull/70\n[11]: https://github.com/klarna/erlavro#decoder-hooks\n[12]: https://www.erlang.org/docs/26/man/ssl#type-client_cacerts\n[13]: https://www.erlang.org/docs/26/man/ssl#type-client_option\n\n# Getting Started\n\nThis Elixir library supports convenient encoding and decoding of [Avro][1] messages.\n\nIt can read the Avro schema from local files or the [Confluent® Schema Registry][2],\ncaching data in memory for performance.\n\nIt supports reading and writing data Kafka [wire format][3] prefix and from [Object Container Files][4]\nformats. Along with [Confluent® Schema References][5] it has [Inter-Schema references][6] feature for\nolder Schema Registry versions.\n\nMany thanks to the [AvroTurf][7] Ruby gem for the initial inspiration :blue_heart:\n\n---\n\n#### If you like the project and want to support me on my sleepless nights, you can\n\n[![Support via PayPal](https://cdn.rawgit.com/twolfson/paypal-github-button/1.0.0/dist/button.svg)](https://www.paypal.com/paypalme/onistrech/eur5.0)\n[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W8367XJ)","ref":"readme.html","title":"README","type":"extras"},{"doc":"Add Avrora to `mix.exs` as a dependency\n\n```elixir\ndef deps do\n  [\n    {:avrora, \"~> 0.30\"}\n  ]\nend\n```","ref":"readme.html#add-avrora-to-your-project","title":"Add Avrora to your project - README","type":"extras"},{"doc":":beginner: It's recommended to configure private Avrora client [v0.17]  to avoid\nrisk of conflicts with other dependencies which might use shared `Avrora` client.\n\nDon't worry if you already using the shared client because migration to the private is a\nmatter of copy-paste.","ref":"readme.html#configuration","title":"Configuration - README","type":"extras"},{"doc":"Create your private Avrora client module\n\n```elixir\ndefmodule MyClient do\n  use Avrora.Client,\n    otp_app: :my_application,\n    schemas_path: \"./priv/schemas\",\n    registry_url: \"http://localhost:8081\",\n    registry_auth: {:basic, [\"username\", \"password\"]},\n    registry_user_agent: \"Avrora/0.30.0 Elixir\",\n    registry_ssl_opts: [verify: :verify_none]\n    registry_ssl_cacerts: File.read!(\"./priv/trusted.der\"),\n    registry_ssl_cacert_path: \"./priv/trusted.crt\",\n    registry_schemas_autoreg: false,\n    convert_null_values: false,\n    convert_map_to_proplist: false,\n    names_cache_ttl: :timer.minutes(5),\n    decoder_hook: &MyClient.decoder_hook/4\nend\n```\n\nplease check the section below :point_down: for detailed explanation of each configuration option.","ref":"readme.html#private-client","title":"Private client - README","type":"extras"},{"doc":"Configure the `Avrora` shared client in `config/config.exs`\n\n```elixir\nconfig :avrora,\n  otp_app: :my_application, # optional, if you want to use it as a root folder for `schemas_path`\n  schemas_path: \"./priv/schemas\",\n  registry_url: \"http://localhost:8081\",\n  registry_auth: {:basic, [\"username\", \"password\"]}, # optional\n  registry_user_agent: \"Avrora/0.30.0 Elixir\", # optional: if you want to return previous behaviour, set it to `nil`\n  registry_ssl_opts: [verify: :verify_none], # optional: if you want to set any available SSL options, overwriting rest\n  registry_ssl_cacerts: File.read!(\"./priv/trusted.der\"), # optional: if you have DER-encoded certificate\n  registry_ssl_cacert_path: \"./priv/trusted.crt\", # optional: if you have PEM-encoded certificate file\n  registry_schemas_autoreg: false, # optional: if you want manually register schemas\n  convert_null_values: false, # optional: if you want to keep decoded `:null` values as is\n  convert_map_to_proplist: false, # optional: if you want to restore the old behavior for decoding map-type\n  names_cache_ttl: :timer.minutes(5), # optional: if you want periodic disk reads\n  decoder_hook: &MyClient.decoder_hook/4 # optional: if you want to amend the data/result\n```\n\n- `otp_app` [v0.22]  - Name of the OTP application to use for runtime configuration via env, default `nil`\n- `schemas_path` - Base path for locally stored schema files, default `./priv/schemas`\n- `registry_url` - URL for the Schema Registry, default `nil`\n- `registry_auth` – Credentials to authenticate in the Schema Registry, default `nil`\n- `registry_user_agent` [v0.25]  - HTTP `User-Agent` header for Schema Registry requests, default `Avrora/  Elixir`\n- `registry_ssl_opts` [v0.30]  - Arbitrary [SSL client options][13] in Erlang format (take precedence over other SSL options), default `nil`\n- `registry_ssl_cacerts` [v0.28]  - DER-encoded certificates, but [without combined support][12], default `nil`\n- `registry_ssl_cacert_path` [v0.28]  - Path to a file containing PEM-encoded CA certificates, default `nil`\n- `registry_schemas_autoreg` [v0.13]  - Flag for automatic schemas registration in the Schema Registry, default `true`\n- `convert_null_values` [v0.14]  - Flag for automatic conversion of decoded `:null` values into `nil`, default `true`\n- `convert_map_to_proplist` [v0.15]  restore old behaviour and confiugre decoding map-type to proplist, default `false`\n- `names_cache_ttl` [v0.10]  - Time in ms to cache schemas by name in memory, default `:infinity`\n- `decoder_hook` [v0.24]  - Function with arity 4 to amend data or result, default `fn _, _, data, fun -> fun.(data) end`\n\nSet `names_cache_ttl` to `:infinity` will cache forever (no more disk reads will\nhappen). This is safe when schemas resolved in the Schema Registry by\nnumeric id or **versioned** name, as it is unique. If you need to reload schema\nfrom the disk periodically, TTL different from `:infinity` ensures that.\n\nIf the schema resolved by name it will be always overwritten with the latest\nschema received from Schema Registry. [v0.10] \n\nCustom [decoder hook][11] will be first in the call-chain, after it's done Avrora\nwill use the result in its own decoder hook. [v0.24] \n\n:bulb: Disable schemas auto-registration if you want to avoid storing schemas\nand manually control registration process. Also it's recommended to turn off auto-registration\nwhen schemas containing [Confluent Schema References][8]. [v0.14] \n\n:bulb: When you use releases and especially Umbrella apps with different clients it's\nrecommended to set `otp_app` which will point to your OTP applications. This will allow you\nto have a per-client runtime resolution for all configuration options (i.e. `schemas_path`)\nwith a fallback to staticly defined in a client itself. [v0.23] \n\n:bulb: If both `registry_ssl_cacerts` and `registry_ssl_cacert_path` given, then\n`registry_ssl_cacerts` has a priority.","ref":"readme.html#shared-client","title":"Shared client - README","type":"extras"},{"doc":"Avrora uses an in-memory cache to speed up schema lookup.","ref":"readme.html#start-cache-process","title":"Start cache process - README","type":"extras"},{"doc":"After you've created your [private Avrora client](#private-client),\nadd it to your supervision tree\n\n```elixir\nchildren = [\n  MyClient\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nor start the process manually\n\n```elixir\n{:ok, pid} = MyClient.start_link()\n```","ref":"readme.html#private-client","title":"Private client - README","type":"extras"},{"doc":"Add shared `Avrora` module to your supervision tree\n\n```elixir\nchildren = [\n  Avrora\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nor start the process manually\n\n```elixir\n{:ok, pid} = Avrora.start_link()\n```","ref":"readme.html#shared-client","title":"Shared client - README","type":"extras"},{"doc":":beginner: All the examples below (including [Schemas registration](#schemas-registration))\nwill use `Avrora` shared client, but if you are using private client,\njust replace `Avrora` with your client module name.\n\nThe primary way to use the library is via the `Avrora.encode/2` and\n`Avrora.decode/2` functions. These functions load the Avro schema for you.\n\nIf `registry_url` defined, it enables Schema Registry storage. If the schema\nfile found locally but not in the registry, either fuction will register the schema.\n\nThese examples assume you have a `Payment` schema stored in the file\n`priv/schemas/io/acme/Payment.avsc`\n\n```json\n{\n  \"type\": \"record\",\n  \"name\": \"Payment\",\n  \"namespace\": \"io.acme\",\n  \"fields\": [\n    {\n      \"name\": \"id\",\n      \"type\": \"string\"\n    },\n    {\n      \"name\": \"amount\",\n      \"type\": \"double\"\n    }\n  ]\n}\n```\n\nWhen running interactively, first make sure the cache started\n\n```elixir\n{:ok, pid} = Avrora.start_link()\n```","ref":"readme.html#usage","title":"Usage - README","type":"extras"},{"doc":"To encode a `Payment` message:\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\")\n<<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n  8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n  144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n  111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n  101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n  101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n  100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34,\n  44, 34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125,\n  44, 123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34,\n  44, 34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125,\n  93, 125, 0, 138, 124, 66, 49, 157, 51, 242, 3, 33, 52, 161, 147, 221, 174,\n  114, 48, 2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 138,\n  124, 66, 49, 157, 51, 242, 3, 33, 52, 161, 147, 221, 174, 114, 48>>\n```\n\nThe `:format` argument controls output format:\n\n- `:plain` deprecated [v0.18]  - Just return Avro binary data, with no header or embedded schema\n- `:ocf` - Use [Object Container File][4]\n  format, embedding the full schema with the data\n- `:registry` - Write data with Confluent Schema Registry\n  [Wire Format][3],\n  which prefixes the data with the schema id\n- `:guess` - Use `:registry` if possible, otherwise use `:ocf` (default)\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\", format: :registry)\n<<0, 0, 42, 0, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n```","ref":"readme.html#encode-2","title":"encode/2 - README","type":"extras"},{"doc":"Decode `Payment` message using the specified schema\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = <<0, 0, 42, 0, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n\n{:ok, decoded} = Avrora.decode(message, schema_name: \"io.acme.Payment\")\n%{\"id\" => \"tx-1\", \"amount\" => 15.99}\n```","ref":"readme.html#decode-2","title":"decode/2 - README","type":"extras"},{"doc":"Decode a message, auto-detecting the schema using magic bytes.\nIt first tries resolving the schema using the integer id in the [wire format][3] header.\n\nNext it tries reading using the [Object Container Files][4] embedded schema.\n\n**NOTE:** Messages encoded with OCF wrapped in a List.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage =\n  <<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n    8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n    144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n    111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n    101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n    101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n    100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125, 44,\n    123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125, 93,\n    125, 0, 84, 229, 97, 195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106,\n    2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 84, 229, 97,\n    195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106>>\n\n{:ok, decoded} = Avrora.decode(message)\n[%{\"id\" => \"tx-1\", \"amount\" => 15.99}]\n```\n\n:bulb: Due to [possible collision][10] of the `:plain` format and `:registry` via magic-like\nbyte sequence it's recommended [v0.18]  to use `Avrora.decode_plain/2` and `Avrora.encode_plain/2` if\nyou are working with `:plain` format (see in all available functions).\n\n \n   :mag: Click to expand for all available functions","ref":"readme.html#decode-1","title":"decode/1 - README","type":"extras"},{"doc":"Decode a message encoded in a `:plain` format.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = <<8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n\n{:ok, decoded} = Avrora.decode(message, schema_name: \"io.acme.Payment\")\n%{\"id\" => \"tx-1\", \"amount\" => 15.99}\n```","ref":"readme.html#decode_plain-2-0-18","title":"decode_plain/2 [0.18] - README","type":"extras"},{"doc":"Encode a payload in a `:plain` format.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage = %{\"id\" => \"tx-1\", \"amount\" => 15.99}\n\n{:ok, encoded} = Avrora.encode(message, schema_name: \"io.acme.Payment\")\n<<8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64>>\n```","ref":"readme.html#encode_plain-2-0-18","title":"encode_plain/2 [0.18] - README","type":"extras"},{"doc":"Extracts a schema from the encoded message, useful when you would like to have\nsome metadata about the schema used to encode the message. All the retrieved schemas\nwill be cached accordingly to the settings.\n\n```elixir\n{:ok, pid} = Avrora.start_link()\nmessage =\n  <<79, 98, 106, 1, 3, 204, 2, 20, 97, 118, 114, 111, 46, 99, 111, 100, 101, 99,\n    8, 110, 117, 108, 108, 22, 97, 118, 114, 111, 46, 115, 99, 104, 101, 109, 97,\n    144, 2, 123, 34, 110, 97, 109, 101, 115, 112, 97, 99, 101, 34, 58, 34, 105,\n    111, 46, 99, 111, 110, 102, 108, 117, 101, 110, 116, 34, 44, 34, 110, 97, 109,\n    101, 34, 58, 34, 80, 97, 121, 109, 101, 110, 116, 34, 44, 34, 116, 121, 112,\n    101, 34, 58, 34, 114, 101, 99, 111, 114, 100, 34, 44, 34, 102, 105, 101, 108,\n    100, 115, 34, 58, 91, 123, 34, 110, 97, 109, 101, 34, 58, 34, 105, 100, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 115, 116, 114, 105, 110, 103, 34, 125, 44,\n    123, 34, 110, 97, 109, 101, 34, 58, 34, 97, 109, 111, 117, 110, 116, 34, 44,\n    34, 116, 121, 112, 101, 34, 58, 34, 100, 111, 117, 98, 108, 101, 34, 125, 93,\n    125, 0, 84, 229, 97, 195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106,\n    2, 26, 8, 116, 120, 45, 49, 123, 20, 174, 71, 225, 250, 47, 64, 84, 229, 97,\n    195, 95, 74, 85, 204, 143, 132, 4, 241, 94, 197, 178, 106>>\n\n{:ok, schema} = Avrora.extract_schema(message)\n{:ok,\n %Avrora.Schema{\n   full_name: \"io.acme.Payment\",\n   id: nil,\n   json: \"{\\\"namespace\\\":\\\"io.acme\\\",\\\"name\\\":\\\"Payment\\\",\\\"type\\\":\\\"record\\\",\\\"fields\\\":[{\\\"name\\\":\\\"id\\\",\\\"type\\\":\\\"string\\\"},{\\\"name\\\":\\\"amount\\\",\\\"type\\\":\\\"double\\\"}]}\",\n   lookup_table: #Reference<0.146116641.3853647878.152744>,\n   version: nil\n }}\n```","ref":"readme.html#extract_schema-1","title":"extract_schema/1 - README","type":"extras"},{"doc":"There are two ways you can register AVRO schemas if you have disabled auto-registration.\n\nIf you want to make it a part of your code, but with better control, you can use\n`Avrora.Utils.Registrar` module and if you want to embed it in the deployment use\na mix task `avrora.reg.schema`.","ref":"readme.html#schemas-registration","title":"Schemas registration - README","type":"extras"},{"doc":"This module is cache-aware and thus it can be used inside intensive loops if needed.\nIt provides two ways to register schema:\n\n- by name, then it will be resolved to a file with [library conventions][9]\n- by schema, then a given schema will be used without any disk reads\n\nBut keep in mind that either way has a memory check to ensure that schema was not\nregistered before and to bypass this check you have to use `force: true` flag\n\n```elixir\n{:ok, schema} = Avrora.Utils.Registrar.register_schema_by_name(\"io.acme.Payment\", force: true)\n```\n\nIn addition, any schema can be registered under different subject via `as: \"NewName\"` option\n\n```elixir\n{:ok, schema} = Avrora.Storage.File.get(\"io.acme.Payment\")\n{:ok, schema_with_id} = Avrora.Utils.Registrar.register_schema(schema, as: \"NewName\")\n```","ref":"readme.html#avrora-utils-registrar-v0-16","title":"Avrora.Utils.Registrar [v0.16] - README","type":"extras"},{"doc":"A separate mix task to register a specific schema or all found schemas in\nschemas folder (see [configuration](#configuration) section).\n\nFor instance, if you configure Avrora schemas folder to be at `./priv/schemas`\nand you want to register a schema `io/acme/Payment.avsc` then you can use\nthis command\n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment\nschema `io.acme.Payment' will be registered\n```\n\nIn addition, any schema can be registered under different subject via `--as` option [v0.16] \n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment --as MyCustomName\nschema `io.acme.Payment' will be registered as `MyCustomName'\n```\n\nIf you would like to register all schemas found under `./priv/schemas` then you\ncan simply execute this command\n\n```console\n$ mix avrora.reg.schema --all\nschema `io.acme.Payment' will be registered\nschema `io.acme.Wrong' will be skipped due to an error `argument error'\n```\n\nAdditional application config to load additional can be set via `--appconfig` option [v0.26] \n\n```console\n$ mix avrora.reg.schema --name io.acme.Payment --appconfig runtime\nschema `io.acme.Payment' will be registered\n```","ref":"readme.html#mix-avrora-reg-schema-v0-12","title":"mix avrora.reg.schema [v0.12] - README","type":"extras"}],"producer":{"name":"ex_doc","version":"0.36.1"},"proglang":"elixir"}